<?php
/*
Plugin Name: WordPress Media Tags
Plugin URI: http://www.destio.de/tools/wordpress-media-tags/
Description: This plugin gives you the ability to use <code>Media Tags</code> for any attachment.
Author: Designstudio, Philipp Speck
Version: 1.0
Author URI: http://www.destio.de/
*/

if ( !class_exists ('wp_media_tags_plugin')) {
	class wp_media_tags_plugin {
	
	function media_tags_textdomain() {
		load_plugin_textdomain( 'wpmtp', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	function media_tags_init() {
		  $labels = array(
			'name' => __( 'Media Tags', 'wpmtp' ),
			'singular_name' => __( 'Media Tag', 'wpmtp' ),
			'search_items' =>  __( 'Search Tags', 'wpmtp' ),
			'popular_items' => __( 'Popular Tags', 'wpmtp'),
			'all_items' => __( 'All Tags', 'wpmtp' ),
			'parent_item' => __( 'Parent Tag', 'wpmtp' ),
			'parent_item_colon' => __( 'Parent Tag:', 'wpmtp' ),
			'edit_item' => __( 'Edit Tag', 'wpmtp' ), 
			'update_item' => __( 'Update Tag', 'wpmtp' ),
			'add_new_item' => __( 'Add New Tag', 'wpmtp' ),
			'new_item_name' => __( 'New Tag Name', 'wpmtp' ),
		  );

		$args = array(
			'labels' => $labels,
			'hierarchical' => true,
    		'show_ui' => true,
    		'query_var' => true,
			'public' => true,
		);

		register_taxonomy('media_tag', attachment, $args);
	}
	
	function media_tags_submenu() {
		add_submenu_page('upload.php', __('Media Tags', 'wpmtp'), __('Media Tags', 'wpmtp'), 'upload_files', 'edit-tags.php?taxonomy=media_tag&post_type=attachment');
	}
	
	function add_media_columns($columns) {  
		$new = array();  
		foreach($columns as $key => $title) {    
			if ($key=='comments') // Put the column before the $key column      
				$new['media_tags'] = __('Media Tags', 'wpmtp');   
			$new[$key] = $title;  
		}  
		return $new;
	}
		
	function fill_media_columns($column_name, $id) {
		switch($column_name) {
		case 'media_tags':
			$admin = get_admin_url();
			$string = "upload.php?";
			$tags = get_the_terms( $id, 'media_tag' );
			if ( !empty( $tags ) ) {
				$out = array();
				foreach ( $tags as $tag )
					$out[] = "<a href='".$string."media_tag=$tag->slug'> " . esc_html(sanitize_term_field('name', $tag->name, $tag->term_id, 'media_tag', 'display')) . "</a>";
				echo join( ', ', $out );
			} else {
				_e('No Tags');
			}
			break;
		default:
			break;
		}		 
	}
	
	function media_tags_query($term, $size) {
		$args = array( 
			'post_type' => 'attachment', 
			'post_mime_type' => 'image',
			'post_status' => 'inherit',
			'tax_query' => array(
					array(
						'taxonomy' => 'media_tag',
						'terms' => $term,
						'field' => 'slug',
					)
				)
		);
		$loop = new WP_Query( $args );
		while ( $loop->have_posts() ) : $loop->the_post();
			$image = wp_get_attachment_image( '', $size, false );
			$url = wp_get_attachment_url();
				$output = '<a href="'.$url.'">'.$image.'</a>';
				echo $output;
		endwhile;
	}	
	
	function media_tags_shortcode($atts) {
		extract( shortcode_atts( array(
			'name' => '',
			'size' => 'thumbnail',
		), $atts ) );
		wp_media_tags_plugin::media_tags_query($name, $size);
	}

	
	} // class wp_media_tags_plugin
}

add_action('init', array('wp_media_tags_plugin','media_tags_textdomain'));
add_action('init', array('wp_media_tags_plugin','media_tags_init'));
add_action('admin_menu', array('wp_media_tags_plugin', 'media_tags_submenu'));
add_filter('manage_media_columns', array('wp_media_tags_plugin', 'add_media_columns'));
add_action('manage_media_custom_column', array('wp_media_tags_plugin', 'fill_media_columns'), 10, 2 );
add_shortcode('mediatag', array('wp_media_tags_plugin', 'media_tags_shortcode'));
?>